<?php

/*
Plugin Name: RTNET SubSync (Integratory.pl)
Version: 1.3
Description: Integracja WooCommerce i Subiekt GT/Subiekt NEXO PRO/Navireo/WAPRO Mag/Symfonia
Author: integratory.pl
Author URI:  https://integratory.pl/
Plugin URI:
 */

if (is_admin()) {
    register_activation_hook(__FILE__, 'rtnetsubsync_install');
    add_action('admin_menu', 'rtnetsubsync_menu');
    add_filter('plugin_action_links_RtnetSubSync/RtnetSubSync.php', 'rtnetsubsync_settings_link');

}

if (!function_exists('rtnetsubsync_menu')) {
    function rtnetsubsync_menu()
    {
        add_submenu_page('tools.php', 'SubSync', 'SubSync', 'edit_dashboard', 'rtnetsubsync_admin', 'rtnetsubsync_admin');
    }
}

if (!function_exists('rtnetsubsync_settings_link')) {
    function rtnetsubsync_settings_link($links)
    {

        $settings_link = '<a href="' . esc_url(add_query_arg('page', 'rtnetsubsync_admin', get_admin_url() . 'tools.php')) . '">' . __('Settings') . '</a>';
        $support_link = '<a href="' . esc_url('https://rtnet.pl/redir/?go=support_woocommerce') . '" target="_blank">' . __('Instrukcja obsługi') . '</a>';

        $links[] = $settings_link;
        $links[] = $support_link;
        return $links;
    }
}

if (!function_exists('rtnetsubsync_install') && is_admin()) {
    include_once __DIR__ . '/Broker/Broker.php';

    function rtnetsubsync_install()
    {
        $broker = new RTNET\Broker(false);
        if (!function_exists('ioncube_loader_version')) {
            die('Nie znaleziono IonCube Loader. Włącz IonCube w konfiguracji Twojego serwera.');
        }
        add_option('rtnetsubsync_version', RTNET\Broker::$version);
        add_option('rtnetsubsync_pdf_invoices', 0);
    }
}

if (!function_exists('rtnetsubsync_admin') && is_admin() && function_exists('ioncube_loader_version')) {
    function rtnetsubsync_admin()
    {
        include_once __DIR__ . '/Broker/Broker.php';
        $current_url = 'http' . (isset($_SERVER['HTTPS']) ? 's' : '') . '://' . "{$_SERVER['HTTP_HOST']}{$_SERVER['REQUEST_URI']}";
        $broker = new RTNET\Broker(false);
        $resetSecrets = isset($_GET['reset']) && $_GET['reset'] == '1';
        $enable_pdf = null;
        if (isset($_GET['enable_pdf'])) {
            $enable_pdf = (int) $_GET['enable_pdf'];
        }

        if ($enable_pdf !== null) {
            update_option('rtnetsubsync_pdf_invoices', (int) $enable_pdf);
        }

        if ($resetSecrets) {
            $broker->CreateSecrets();
            $back_url = rtrim(str_replace('reset=1', '', $current_url), '&');
            if (!wp_redirect($back_url)) {
                echo '<script>location.href=\'' . $back_url . '\';</script>';
            }
            wp_die();
        }

        $secrets = $broker->GetSecrets();
        $broker_address = rtrim(plugins_url(), '/') . '/RtnetSubSync/Broker/Broker.php';
        $reset_url = $current_url . (strpos($current_url, '?') === false ? '?' : '&') . 'reset=1';
        $enable_pdf_url = $current_url . (strpos($current_url, '?') === false ? '?' : '&') . 'enable_pdf=1';
        $disable_pdf_url = $current_url . (strpos($current_url, '?') === false ? '?' : '&') . 'enable_pdf=0';
        $pdf_invoices_enabled = get_option('rtnetsubsync_pdf_invoices') == 1;

        echo '<h1 class="">RTNET SubSync - parametry konfiguracyjne</h1>'
        . '<table class="form-table">'
        . '<tbody>'
        . '<tr>'
        . '<th scope="row" class="titledesc">Adres brokera</th>'
        . '<td class="forminp"><input type="text" value="' . $broker_address . '" style="width: 95%;" readonly /></td>'
        . '</tr>'
        . '<tr>'
        . '<th scope="row" class="titledesc">Klucz Secret</th>'
        . '<td class="forminp"><input type="text" value="' . $secrets['secret'] . '" style="width: 95%;" readonly /></td>'
        . '</tr>'
        . '<tr>'
        . '<th scope="row" class="titledesc"></th>'
        . '<td class="forminp"><a href="#" onclick="rtCopyToClipboard(); return false;">Kopiuj do schowka</a> <input type="text" id="__fc" value="' . base64_encode('[[' . $broker_address . '|' . $secrets['secret'] . ']]') . '" style="display: none !important;" /></td>'
        . '</tr>'
        . '<tr>'
        . '<th scope="row" class="titledesc">Resetuj secrety</th>'
        . '<td class="forminp"><a href="' . htmlspecialchars($reset_url) . '" onclick="return confirm(\'Czy na pewno zresetować klucz secret? Po tej operacji będzie wymagana ich aktualizacja konfiguracji SubSync\');">Kliknij tutaj, aby zresetować klucz</a></td>'
        . '</tr>'
        . '<tr>'
        . '<th scope="row" class="titledesc">Dokumenty sprzedaży w PDF</th>'
        . '<td class="forminp">'
        . ($pdf_invoices_enabled ? '&#10003; Włączone' : '&#10060; Wyłączone')
        . '. <a href="' . htmlspecialchars($pdf_invoices_enabled ? $disable_pdf_url : $enable_pdf_url) . '">Kliknij tutaj, aby ' . ($pdf_invoices_enabled ? 'wyłączyć' : 'włączyć') . '</a></td>'
            . '</tr>'
            . '</tbody>'
            . '</table>';
        echo "
			<script>
			function rtCopyToClipboard() {
				var node = document.getElementById('__fc');
				node.style = '';
				node.focus();
				node.select();
				document.execCommand('copy');
				node.style = 'display: none !important;';
			}
			</script>
			";
    }
}

/// moduł faktur w pdf
if (get_option('rtnetsubsync_pdf_invoices') == 1 && function_exists('ioncube_loader_version')) {

    include_once __DIR__ . '/Broker/Broker.php';

    if (!function_exists('rt_woocommerce_my_account_my_orders_columns')) {
        function rt_woocommerce_my_account_my_orders_columns($cols)
        {
            $cols['order-rt-invoice'] = __('Dokument sprzedaży');
            return $cols;
        }
        add_filter('woocommerce_my_account_my_orders_columns', 'rt_woocommerce_my_account_my_orders_columns');
    }

    if (!function_exists('woocommerce_my_account_my_orders_column_order_rt_invoice')) {
        function woocommerce_my_account_my_orders_column_order_rt_invoice($order)
        {
            if ($order) {
                $invoice = $order->get_meta('rt-invoice');
                $dir = RTNET\Store::PreparePdfDir('dir');
                $url = RTNET\Store::PreparePdfDir('url');

                $path = $dir . '/' . sanitize_file_name($invoice);
                $url = $url . '/' . sanitize_file_name($invoice);

                if ($invoice && file_exists($path)) {
                    echo '<a href="' . htmlspecialchars($url) . '" class="woocommerce-button button rt-invoice" target="_blank">' . __('Pobierz') . '</a>';
                }
            }
        }
        add_action('woocommerce_my_account_my_orders_column_order-rt-invoice', 'woocommerce_my_account_my_orders_column_order_rt_invoice', 10);
    }

    if (is_admin()) {
        if (!function_exists('rt_woocommerce_my_account_my_orders_actions')) {
            function rt_woocommerce_my_account_my_orders_actions($order)
            {
                if ($order) {
                    $invoice = $order->get_meta('rt-invoice');
                    $dir = RTNET\Store::PreparePdfDir('dir');
                    $url = RTNET\Store::PreparePdfDir('url');

                    $path = $dir . '/' . sanitize_file_name($invoice);
                    $url = $url . '/' . sanitize_file_name($invoice);

                    if ($invoice && file_exists($path)) {
                        echo '<a class="button wc-action-button wc-action-button-rt-invoice rt-invoice link" href="' . htmlspecialchars($url) . '" aria-label="' . __('Pobierz dokument sprzedaży') . '" title="' . __('Pobierz dokument sprzedaży') . '" target="_blank">' . __('Pobierz dokument sprzedaży') . '</a>';
                    }
                }
            }
            add_action('woocommerce_admin_order_actions_end', 'rt_woocommerce_my_account_my_orders_actions');
        }
    }
}
